#!/bin/bash

PRELEASE="indt3"
PNAME="python-efl-core"
PVER="0.1.1_$PRELEASE"
SECTION="libs"

DEF_PKGS="python-evas python-ecore python-edje"

DESC="Enlightenment Foundation Libraries Core - Python Bindings"
LONG_DESC="\
 This package includes: $DEF_PKGS
 .
 Homepage: http://www.enlightenment.org/
"
BDEPENDS="pkg-config"
DEPENDS="efl-core (>= 0.9.9.040_indt3), python2.5"

ARCH="$(arch)"

export CFLAGS="$CFLAGS -DNDEBUG=1 -fomit-frame-pointer -O2 -mfpu=vfp -mfloat-abi=softfp -mcpu=arm1136jf-s -ffast-math -funsafe-math-optimizations -fno-math-errno -fsingle-precision-constant"
DESTDIR="/tmp/$PNAME-$ARCH"

PKGS="$@"
if [ x"$PKGS" = x ]; then
	PKGS=$DEF_PKGS
fi

die() {
	echo "ERROR: $@"
	exit 1
}

if [ x"$NODESTDIR" != x1 ]; then
    rm -fr $DESTDIR
    mkdir -p $DESTDIR
fi

LOG_PREFIX="$(basename $0)"

CWD=$PWD
for p in $PKGS; do
    PKG_OPTS_NAME="OPTS_$p"
    PKG_OPTS="${!PKG_OPTS_NAME}"
    LOG="/tmp/${LOG_PREFIX}__$p.log"

    echo "Build: $p"
    echo "$(date) ---- $p" >> "$LOG"
    cd $CWD/$p || die "missing package $p"

    m=`echo "$p" | sed s/python-//g`
    touch $m/$m.c_$m.pyx
    python2.5 setup.py build_ext build install --prefix /usr install_headers
    python2.5 setup.py install --root $DESTDIR

    cd $CWD
done

if [ x"$NODESTDIR" != x1 ]; then
    cd $DESTDIR
    tar czf $DESTDIR.tar.gz .
    cd $CWD
fi

##
## Clean
##
find $DESTDIR/usr/lib -name '*.a' -exec rm \{\} \;
find $DESTDIR/usr/lib -name '*.la' -exec rm \{\} \;
find $DESTDIR/usr/lib -name '*.egg-info' -exec rm -fr \{\} \;
find $DESTDIR/usr/lib -name '*.so' -exec strip -s \{\} \;
rm -fr $DESTDIR/usr/include
rm -fr $DESTDIR/usr/bin/*-config
rm -fr $DESTDIR/usr/lib/pkgconfig
SIZE=$(du -sc $DESTDIR | grep total | sed s/total//)

##
## Package
##
PDIR="${DESTDIR}-deb"
mkdir -p $PDIR
cd $PDIR
cat > control <<EOF
Package: $PNAME
Version: $PVER
Section: $SECTION
Priority: optional
Architecture: armel
Installed-Size: $SIZE
Maintainer: Gustavo Sverzut Barbieri <gustavo.barbieri@openbossa.org>
Build-Depends: $BDEPENDS
Depends: $DEPENDS
Description: $DESC
$LONG_DESC
EOF
echo 2.0 > debian-binary
tar czf control.tar.gz control
(cd $DESTDIR; tar czf $PDIR/data.tar.gz .)
rm -f ${PNAME}_${PVER}_armel.deb
ar q ${PNAME}_${PVER}_armel.deb debian-binary control.tar.gz data.tar.gz
echo $PWD/${PNAME}_${PVER}_armel.deb
